Database

Struct Database 

pub struct Database(/* private fields */);
An IDBDatabase implementation.

Implementations

Source

impl Database

pub fn open<N>(name: N) -> OpenDbRequestBuilder<N>
where N: AsRef<str>,

Open a database with the given name. Convenience method for OpenDbRequestBuilder::new - use it when opening multiple databases.

Errors
ErrorThrown when
InvalidStateErrorThrown if the method was not called from a Versionchange transaction callback.
TransactionInactiveErrorThrown if a request is made on a source database that does not exist (for example, when the database has been deleted or removed).
ConstraintErrorThrown if an object store with the given name (based on a case-sensitive comparison) already exists in the connected database.
InvalidAccessErrorThrown if autoIncrement is set to true and keyPath is either an empty string or an array containing an empty string.
pub fn create_object_store<N>(&self, name: N) -> StoreBuilder<'_, N>
where N: AsRef<str>,

Create an object store with the given name.

pub fn close(self)

Close the database connection in a background thread.

pub fn delete(self) -> Result<Request<()>, OpenDbError>

Close and delete the database.

Errors

Undocumented as of the release of this version.

pub fn delete_object_store(&self, name: &str) -> Result<(), Error>

Delete the object store with the given name.

Errors
ErrorThrown when
InvalidStateErrorThrown if the method was not called from a Versionchange transaction callback.
TransactionInactiveErrorThrown if a request is made on a source database that does not exist (for example, when the database has been deleted or removed).
NotFoundErrorThrown when trying to delete an object store that does not exist.
pub fn name(&self) -> String

Get the database name.

pub fn object_store_names(&self) -> DomStringIter<'_>

List the names of the object stores within this database.

pub fn transaction<S>(&self, store_names: S) -> TransactionBuilder<'_, S>
where S: ObjectStoreName,

Start a transaction on the given store name(s). Finish the builder with a call to Build::build.

Errors
ErrorThrown when
NotFoundErrorThrown if an object store specified cannot be found.
InvalidAccessErrorThrown if the fn was called with an empty list of store names.
pub fn version(&self) -> f64

Get the database version.

pub fn delete_by_name(name: &str) -> Result<Request<()>, OpenDbError>

Delete the database with the given name. Convenience method for DBFactory::delete_db - use that if you need to delete more than one database.

Errors

Undocumented as of the release of this version.